@@ -39,7 +39,6 @@ def download_from_url(url, dst):
         # print("文件已经存在,无需下载")
         return file_size
 
-    print('Downloading the required environment, Please wait.')
     # #删除不完整的文件
     # try:
     #     os.remove(dst)
@@ -53,15 +52,17 @@ def download_from_url(url, dst):
 
     # 访问url进行下载
     req = requests.get(url, headers=headers, stream=True)
-    try:
-        with(open(dst, 'ab')) as f:
-            for chunk in req.iter_content(chunk_size=1024):
-                if chunk:
-                    f.write(chunk)
-                    pbar.update(1024)
-    except Exception as e:
-        print(e)
-        return False
+
+    #循环下载
+    files = []
+    for chunk in req.iter_content(chunk_size=1024):
+        if chunk:
+            files.append(chunk)
+            pbar.update(1024)
+        
+    with(open(dst, 'ab')) as f:
+        for chunk in files:
+            f.write(chunk)
 
     pbar.close()
     return True
\ No newline at end of file
